@@ -1,9 +1,6 @@
 ## no critic (RequireUseStrict)
 package Net::Proxy::Connector::tcp_balance;
-{
-  $Net::Proxy::Connector::tcp_balance::VERSION = '0.002';
-}
-
+$Net::Proxy::Connector::tcp_balance::VERSION = '0.003';
 ## use critic (RequireUseStrict)
 use strict;
 use warnings;
@@ -14,27 +11,33 @@ use base "Net::Proxy::Connector::tcp";
 sub connect {
     my @params = @_;
     my ($self) = shift @params;
-    for ( sort {int(rand(3))-1} @{$self->{hosts}} ) {
+    my @hosts_sorted = sort {int(rand(3))-1} @{$self->{hosts}};
+    if ( $self->{sort} and $self->{sort} eq 'order' ){
+        @hosts_sorted = sort @{$self->{hosts}};
+    }
+    elsif ( $self->{sort} and $self->{sort} eq 'none' ){
+        @hosts_sorted = @{$self->{hosts}};
+    }
+    for ( @hosts_sorted ) {
         $self->{host} = $_;
         my $sock = eval { $self->SUPER::connect(@params); };
         return $sock if $sock;
     }
-
 }
 
 1;
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Net::Proxy::Connector::tcp_balance
+Net::Proxy::Connector::tcp_balance - A Net::Proxy connector for outbound tcp balancing and failover
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -95,6 +98,10 @@ The remote hosts.  An array ref.
 
 The remote port.
 
+=item * sort
+
+(Optional) Connect to the hosts in sort algorithm.  Possible values: order, none, random.  Default is random.
+
 =item * timeout
 
 The socket timeout for connection (C<out> only).
@@ -107,14 +114,13 @@ Jesse Thompson <zjt@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Thompson.
+This software is copyright (c) 2015 by Jesse Thompson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 
 # ABSTRACT: A Net::Proxy connector for outbound tcp balancing and failover
